#!/bin/bash
# author           : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# last revised     : 22/09/2007
# homepage         : http://www.freetype.org/jam/#where-ftjam

softname='ftjam'
softversion='2.5.2'
packageversion='48.1'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/src/$softname-$softversion

# slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: Build tool that can be used as a replacement for Make
$softname: 
$softname: Even though Jam is a lot simpler to use than Make, it is far
$softname: more powerful and easy to master. 
$softname:  
$softname:   
$softname: 
$softname: 
$softname: 
$softname:
$softname: 
EOF

# extract the source code
cd $buildir
tar zxvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"   
    
    ./configure \
      --prefix=$prefix \
      --mandir=/usr/man \
      --sysconfdir=/etc \
      --localstatedir=/var/lib \
      --datadir=/usr/share \
      --build=$arch-slackware-linux
     
    make
    make install DESTDIR=$dest

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      CHANGES INSTALL README README.ORG RELNOTES Porting Jam.html Jambase.html Jamfile.html \
      $dest/usr/doc/$softname-$softversion 

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# put the ZenWalk build in the right directory
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
